
Toplevel functions
==================

Matching
^^^^^^^^
.. autofunction:: jertl.match
.. autofunction:: jertl.match_all
.. autofunction:: jertl.compile_match

Filling
^^^^^^^
.. autofunction:: jertl.fill
.. autofunction:: jertl.compile_fill

Transforming
^^^^^^^^^^^^
.. autofunction:: jertl.transform
.. autofunction:: jertl.transform_all
.. autofunction:: jertl.compile_transform

Collating
^^^^^^^^^
.. autofunction:: jertl.collate
.. autofunction:: jertl.collate_all
.. autofunction:: jertl.compile_collate

Inferring
^^^^^^^^^
.. autofunction:: jertl.infer
.. autofunction:: jertl.infer_all
.. autofunction:: jertl.compile_rule
